@@ -7,6 +7,7 @@ from lcyframe import BaseSchema as Schema
 from lcyframe import utils
 from utils import errors, helper, keys, constant
 
+
 class BaseHandler(Handler):
     """
     This is the base class RequestHandler you apply
@@ -18,7 +19,6 @@ class BaseHandler(Handler):
     constant = constant
     logging = logging
 
-
     def write_pagination(self, datas, counts, **kwargs):
         """
         返回列表
@@ -103,7 +103,11 @@ class BaseSchema(Schema):
                 continue
             docs[k] = v
 
-        data = BaseModel.mysql.insert(cls.collection, docs)
+        # 转为`field_name`兼容保留关键字
+        COMPATIBLE_docs = {}
+        for k, v in docs.items():
+            COMPATIBLE_docs[f"`{k}`"] = v
+        data = BaseModel.mysql.insert(cls.collection, COMPATIBLE_docs)
         if data and hasattr(cls, "_parse_data"):
             return cls._parse_data(data)
         else:
@@ -111,6 +115,7 @@ class BaseSchema(Schema):
 
     @classmethod
     def update_data(cls, id, **kwargs):
+        kwargs.pop("create_time", "")
         kwargs["update_time"] = utils.datetime.now()
         sql_condition, sql_params = cls.get_value_symbol(kwargs, "set")
         sql = f"update {cls.collection} set {sql_condition} where id=%s"
@@ -130,7 +135,7 @@ class BaseSchema(Schema):
         sql_cond, sql_params = cls.get_value_symbol(kwargs)
         sql = f"select {values} from {cls.collection} where {sql_cond}"
         data = BaseModel.mysql.select_one(sql, sql_params)
-        if data and  hasattr(cls, "_parse_data"):
+        if data and hasattr(cls, "_parse_data"):
             return cls._parse_data(data)
         else:
             return data
@@ -144,7 +149,7 @@ class BaseSchema(Schema):
         ref: 查询id在数组[1, 2, 3]内的记录，并返回id，name字段
         ... get_batch_by_in(id, name, id=[1, 2, 3])
         """
-        field = kwargs.pop("field", "id")
+        field = kwargs.pop("field", "")
         return_structure = kwargs.pop("return_structure", "dict")
         # values = ",".join(args) or "*"
         # sql_cond, sql_params = cls.get_value_symbol(kwargs)
@@ -152,10 +157,11 @@ class BaseSchema(Schema):
         if len(kwargs) > 1:
             raise Exception("one condition parameter is required, you give %s" % len(kwargs))
         key, in_values = list(kwargs.items())[0]
-        in_values = list(in_values) if not isinstance(in_values, (list, tuple)) else []
+        field = field or key or "id"
+        in_values = list(in_values) if not isinstance(in_values, (list, tuple)) else in_values
         kw = {}
-        kw["values"] = list(set([field] + list(args)))
-        kw["sql_and"] = {key: {"in": set(in_values)}}
+        kw["values"] = "*" if not args else list(set([field] + list(args)))
+        kw["sql_and"] = {key: {"in": list(set(in_values))}}
         sql, sql_params = cls.get_sql_and_params(**kw)
         datas = BaseModel.mysql.select_many(sql, sql_params)
         if return_structure == "list":
@@ -166,6 +172,31 @@ class BaseSchema(Schema):
     @classmethod
     def get_data_by_spec(cls, *args, **kwargs):
         """
+        查询单条数据
+        args： 需要返回的字段列表
+        kwargs参数含义：
+        sql_and： and条件
+            {"a":1, "b":-1, "c": {"in": [1, 2, 3]}}
+        sql_or: or条件
+            {"x":1, "y":1}
+        orderby： 排序
+            {"a":1, "b":-1} a升序，b将序，无序
+            [("a", 1), ("b", -1)] a升序，b将序
+        page: 页码skip-1
+        count: 每页数limit
+        """
+        kwargs["values"] = args
+        sql, params = cls.get_sql_and_params(**kwargs)
+        data = BaseModel.mysql.select_one(sql, params)
+        if data and hasattr(cls, "_parse_data"):
+            return cls._parse_data(data)
+        else:
+            return data
+
+    @classmethod
+    def get_datas_by_spec(cls, *args, **kwargs):
+        """
+        查询多条数据
         args： 需要返回的字段列表
         kwargs参数含义：
         sql_and： and条件
@@ -206,7 +237,7 @@ class BaseSchema(Schema):
         sql, params = cls.get_sql_and_params(**kwargs)
         counts = cls.get_data_counts(sql, params)
         orderby = orderby if isinstance(orderby, (list, tuple)) else orderby.items()
-        items = ["%s %s" % (k, "ASC" if v >= 1 else "DESC") for k, v in orderby]
+        items = ["`%s` %s" % (k, "ASC" if v >= 1 else "DESC") for k, v in orderby]
         orderby_condition = ",".join(items) if items else ""
         if orderby_condition:
             sql += " order by " + orderby_condition
@@ -264,6 +295,7 @@ class BaseSchema(Schema):
             raise Exception("sql must be provided, if you given params")
         if not sql:
             if values:
+                values = cls.format_fields_name(values)
                 values = values if isinstance(values, str) else ",".join(values)
             else:
                 values = "*"
@@ -286,7 +318,7 @@ class BaseSchema(Schema):
         # groupby
         groupby = kwargs.pop("groupby", [])
         if groupby:
-            items = ["%s" for _ in groupby]
+            items = ["`%s`" for _ in groupby]
             groupby_condition = ",".join(items) if items else ""
             if groupby_condition:
                 params.extend(groupby)
@@ -297,7 +329,7 @@ class BaseSchema(Schema):
         orderby = kwargs.pop("orderby", [])
         if orderby:
             orderby = orderby if isinstance(orderby, (list, tuple)) else orderby.items()
-            items = ["%s %s" % (k, "ASC" if v >= 1 else "DESC") for k, v in orderby]
+            items = ["`%s` %s" % (k, "ASC" if v >= 1 else "DESC") for k, v in orderby]
             orderby_condition = ",".join(items) if items else ""
         else:
             orderby_condition = ""
@@ -344,18 +376,18 @@ class BaseSchema(Schema):
                 value = condition
 
             if symbol.lower() == "=":
-                symbol_str.append(f"{k}{symbol}%s")
+                symbol_str.append(f"`{k}`{symbol}%s")
                 sql_params.append(value)
             elif symbol.lower() == "between":
-                symbol_str.append(f"{k} {symbol} %s and %s")
+                symbol_str.append(f"`{k}` {symbol} %s and %s")
                 sql_params.append(value[0])
                 sql_params.append(value[1])
             elif symbol.lower() in ["in"]:
                 if value:
-                    symbol_str.append(f"{k} {symbol} %s")
+                    symbol_str.append(f"`{k}` {symbol} %s")
                     sql_params.append(tuple(value))
             else:
-                symbol_str.append(f"{k} {symbol} %s")
+                symbol_str.append(f"`{k}` {symbol} %s")
                 sql_params.append(value)
 
             return symbol_str, sql_params
@@ -412,3 +444,16 @@ class BaseSchema(Schema):
                         continue
 
         return docs
+
+    @classmethod
+    def format_fields_name(cls, fields):
+        """
+        字段名称加上``，避免误用保留字导致sql语句错误
+        """
+        if isinstance(fields, str):
+            return f"`{fields}`"
+        else:
+            symbol_fields = []
+            for k in fields:
+                symbol_fields.append(f"`{k}`")
+            return symbol_fields
\ No newline at end of file
