@@ -6,7 +6,7 @@ from lcyframe import funts
 from base import BaseHandler, helper
 import re
 
-@route("/upload")
+@route("/upload", name="upload")
 class UploadHeadHandler(BaseHandler):
     """
     上传
