@@ -5,6 +5,12 @@ import logging
 root_dir = os.path.dirname(os.path.dirname(__file__))
 sys.path.append(root_dir)
 
+import os, sys
+import re, requests
+import logging
+root_dir = os.path.dirname(os.path.dirname(__file__))
+sys.path.append(root_dir)
+
 from context import InitContext
 from lcyframe.libs.singleton import MongoCon
 from lcyframe.libs.cprint import cprint
@@ -46,9 +52,9 @@ def send(methed, url, params, **kwargs):
 
     if "token" not in kwargs["headers"]:
         response = login()
-        if response["code"] != 0:
+        if response.get("code"):
             raise Exception(response["msg"])
-        user = response["data"]
+        user = response
         token = user["token"]
         user_id = user["user_id"]
         HEARDERS["user_id"] = user_id
@@ -68,16 +74,19 @@ def send(methed, url, params, **kwargs):
         _url = config["wsgi"]["host"] + ":" + str(config["wsgi"]["port"])
     _url += url
 
-
     if methed == "delete":
         kwargs["data"] = params
         data = eval("requests.%s" % methed)(_url, **kwargs)
     else:
         data = eval("requests.%s" % methed)(_url, params, **kwargs)
 
-    r = data.json()
-    cprint(r)
-    return r
+    response = data.json()
+    if response["code"] == 0:
+        data = response["data"]
+    else:
+        data = response
+    cprint(data)
+    return data
 
 def get(url, params, **kwargs):
     send("get", url, params, **kwargs)
@@ -90,5 +99,3 @@ def put(url, params, **kwargs):
 
 def delete(url, params, **kwargs):
     send("delete", url, params, **kwargs)
-
-
