@@ -8,18 +8,23 @@ from lcyframe.libs import cprint, utils
 def get_websocket(*args, **kwargs):
     """
     websocket链接测试:
-    
-    参数:
-    - nickname # 选填，,string,用户昵称
     """
     headers = {}
     files = {}
     params = {
-        "nickname": "(选填)用户昵称",
+        "nickname": "",     # string,选填,用户昵称
         }
     return send(methed="get", url="/websocket", params=params, headers=headers, files=files)
 
 
+def batch_groups():
+    """
+    测试簇
+    一键测试
+    """
+    get_websocket()       # websocket链接测试
+    
+
 if __name__ == "__main__":
     # websocket链接测试
     get_websocket()
