@@ -147,6 +147,8 @@ def app(permission_bit=0):
     """
     应用端访问： app web
     :param permission_bit:
+        0： anybody、anonymous 游客、匿名用户
+        1： login user登录用户
     :return:
     """
     def wrap(method):
@@ -174,6 +176,8 @@ def admin(permission_bit=0):
     管理后台验证: jtw
     支持多个客户端同时访问
     :param permission_bit:
+        0： anybody、anonymous 游客、匿名用户
+        1： login user登录用户
     :return:
     """
 
@@ -220,6 +224,8 @@ def api(permission_bit=1):
     通常用于开发者远程调用
     Aes加密
     :param permission_bit:
+        0： anybody、anonymous 游客、匿名用户
+        1： login user登录用户
     :return:
     """
 
