@@ -7,8 +7,7 @@ from lcyframe.libs.celery_route import BaseEvent
 @shared_task(ignore_result=False)  # 普通函数装饰为 celery task
 def save_image(x):
     """
-    seleep时间随机
-    任务多线程并发执行，谁先执行完毕，谁先输出结果
+    self.application.celery.save_image.delay(111)
     :param x:
     :return:
     """
@@ -21,12 +20,11 @@ def save_image(x):
 
 class UserEvent(BaseEvent):
     @staticmethod
-    @shared_task(ignore_result=False)  # 普通函数装饰为 celery task
+    @shared_task(ignore_result=False)
     def register(x):
         """
-        sleep时间随机
-        任务多线程并发执行，谁先执行完毕，谁先输出结果
-        :use self.application.celery.DefaultEvent.add.delay(111)
+        按类名划分任务组
+        :use self.application.celery.UserEvent.register.delay(111)
         :param x:
         :return:
 
