@@ -139,9 +139,9 @@ class ErrorStateError(ApiError):
     通用类：状态不符合
     """
     code = 702
-    code_name = 'ErrorNotData'
-    message = 'ErrorNotData'
-    zh_message = '状态不符合'
+    code_name = 'ErrorStateError'
+    message = 'ErrorStateError'
+    zh_message = '状态错误'
 
 # 权限类错误90x
 class ErrorNoApiPermission(ApiError):
