@@ -36,11 +36,7 @@ lcy_format = '[{name}] %(levelname)s\n[{name}] path: %(pathname)s:%(lineno)d\n[{
 class Logger(object):
     instance = {}
 
-    def __init__(self, name, level='info', when='D', backCount=10, fmt=None, save_path=None, propagate=True):
-        if not fmt:
-            fmt = lcy_format.format(name=name)
-        else:
-            fmt = default_fmt
+    def __init__(self, name, level='info', when='D', backCount=10, fmt=default_fmt, save_path=None, propagate=True):
         self.propagate = propagate
         self.logger = logging.getLogger(name)
         self.logger.propagate = self.propagate           # 输出的信息不推送给上级的logger，即root
@@ -74,7 +70,9 @@ class Logger(object):
 
 if __name__ == '__main__':
     # app 专用log
-    app = Logger.get_instance(name="Lcyframe", level='debug')
+    name = "Lcyframe"
+    fmt = lcy_format.format(name=name)
+    app = Logger.get_instance(name=name, level='debug', fmt=fmt)
     app.logger.debug('debug')
     app.logger.info('info')
     app.logger.warning('警告')
