@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 import logging
-import functools
-import sys, os
+import os
 from .context_start import AutoStartContext
 from lcyframe.libs import utils
 
@@ -26,13 +25,10 @@ class ServicesFindet(object):
     def import_mongo(self, config):
         f = config.get("mongo_config", {})
         if f:
-            AutoStartContext.start_mongodb(f)
             from .singleton import MongoCon
-            from .permissions import Permission
+            AutoStartContext.start_mongodb(f)
             self.__mount_attribute("mongo", MongoCon.get_database(**f))
 
-            Permission.mongo = MongoCon.get_database(**f)
-            self.__mount_attribute("Permission", Permission.initial())
             return True
 
     def import_mysql(self, config):
@@ -42,6 +38,23 @@ class ServicesFindet(object):
             self.__mount_attribute("mysql", PyMysqlCon.get_connection(**f))
             return True
 
+    def import_permission(self, config):
+        f = config.get("permission", {})
+        if not f.get("enable", False):
+            return
+
+        # 类rbac模式，暂支持mysql
+        if f.get("module", 1) == 1 and hasattr(self.app, "mysql"):
+            from lcyframe.libs.permission.rbac import RBACPermission
+            self.__mount_attribute("Permission", RBACPermission.initial())
+        # 权限位模式, 仅支持mongo
+        elif f.get("module") == 2 and hasattr(self.app, "mongo"):
+            from lcyframe.libs.permission.bit import BitPermission
+            from .singleton import MongoCon
+            BitPermission.mongo = MongoCon.get_database(**config.get("mongo_config", {}))
+            self.__mount_attribute("Permission", BitPermission.initial())
+
+
     def import_redis(self, config):
         f = config.get("redis_config")
         if f:
