@@ -126,6 +126,7 @@ class TypeConvert(object):
     """类型转换类, 处理参数"""
     MAP = {int: int,
            float: float,
+           list: list,
            bool: bool,
            str: str}
 
@@ -483,15 +484,24 @@ def check_ssrf_url(url):
     http://10.0.0.1#123.123.123.123
     当request.get(url)时，实际请求10.0.0.1，存在安全隐患
     """
-    schema = urlparse(url).scheme
-    hostname = urlparse(url).hostname
+    schema = urlparse(url).scheme or None
+    hostname = urlparse(url).hostname or url
     try:
         if not verify_domain(url):
             return ""
-        ip_address = socket.getaddrinfo(hostname, 'http')[0][4][0]
-        if check_internal_ip(ip_address):
-            return ""
-        return schema + "://" + hostname
+        # ip_address = socket.getaddrinfo(hostname, schema)[0][4][0]
+        ip_address = ""
+        AddressFamily = ""
+        for item in socket.getaddrinfo(hostname, schema):
+            AddressFamily = item[0]
+            if AddressFamily == socket.AddressFamily.AF_INET:
+                ip_address = item[4][0]
+                break
+
+        if AddressFamily == socket.AddressFamily.AF_INET:
+            if check_internal_ip(ip_address):
+                return ""
+        return (schema or "http") + "://" + hostname
     except Exception as e:
         return ""
 
@@ -539,7 +549,7 @@ def safe_request_url(url, **kwargs):
 
     all_hooks['response'] = r_hooks
     kwargs['hooks'] = all_hooks
-    return requests.get(url, **kwargs)
+    return requests.get(safe_url, **kwargs)
 
 def verify_username(username, min: int = 4, max: int = 10):
     """
@@ -670,9 +680,17 @@ def verify_ip(ip, IPv6=True):
     ipv4_re = r"^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"  # IPV4
     ipv6_re = r"^(?:[A-F0-9]{1,4}:){7}[A-F0-9]{1,4}$"  # IPV6
     if IPv6:  # 大小写不敏感
-        return re.search(ipv4_re, ip, re.I) or re.search(ipv6_re, ip)
+        return re.search(ipv6_re, ip, re.I) or re.search(ipv6_re, ip)
     else:
         return re.search(ipv4_re, ip)
+def _get_protocol(domain):
+    if domain.startswith("https://"):
+        protocol = "https://"
+    elif domain.startswith("http://"):
+        protocol = "http://"
+    else:
+        protocol = ""
+    return protocol
 
 def verify_domain(domain, mtype=1):
     """
@@ -682,17 +700,12 @@ def verify_domain(domain, mtype=1):
         2提取域名有效部分：https://7w.7.wx.baidu.com >> 7w.7.wx.baidu.com
     :return:
     """
-    if domain.startswith("https://"):
-        protocol = "https://"
-    elif domain.startswith("http://"):
-        protocol = "http://"
-    else:
-        protocol = ""
+    protocol = _get_protocol(domain)
     domain_re = r'\b((?=[a-z0-9-]{1,63}\.)(xn--)?[a-z0-9]+(-[a-z0-9]+)*\.)+[a-z]{2,63}\b'
     result = re.search(domain_re, domain, re.I)
     if result:
         if mtype == 1:
-            return result.group() == domain.strip(protocol)
+            return result.group() == domain.replace(protocol, "")
         else:
             return result.group()
     else:
@@ -704,12 +717,15 @@ def extract_domain(domain):
     domain: http://news.baidu.com
     tld = extract_domain(domain)
         >>> ExtractResult(subdomain='news', domain='baidu', suffix='com')
-        >>> tld[0]
-        >>> tld[1]
-        >>> tld[2]
-    tld.registered_domain
-        >>> baidu.com
+        >>> tld[0] or tld.subdomain == "news"
+        >>> tld[1] or tld.domain   == "baidu"
+        >>> tld[2] or tld.suffix == "com"
+        >>> tld.registered_domain == "baidu.com"
+
     """
+    # urllib3.get_host(url)[1] or ''    # http://news.baidu.com >> news.baidu.com
+    # urllib3.get_host(url)[1] or ''    # http://www.baidu.com >> www.baidu.com
+
     import tldextract
     tld = tldextract.extract(domain)
     return tld
@@ -966,7 +982,7 @@ def imagecode(stype=4, args_value=None, return_type=2, filename=None, **kwargs):
 
     """
     from .gvcode import VFCode
-    kwargs = kwargs if kwargs else dict(
+    default_kw = dict(
         font_background_value='#87CEFF',
         draw_dots=True,
         dots_width=5,
@@ -976,7 +992,9 @@ def imagecode(stype=4, args_value=None, return_type=2, filename=None, **kwargs):
         lines_count=10,
         lines_background_value="#ffffff",
     )
-    vc = VFCode(**kwargs)
+    if kwargs:
+        default_kw.update(kwargs)
+    vc = VFCode(**default_kw)
 
     mp = {
         # 自定义验证码
